==> iTop-3.2.0-2-14758.zip: web/datamodels/2.x/itop-core-update/dictionaries/es_cr.dict.itop-core-update.php <==
<?php
/**
 * Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * 
 */
/**
 * @author Miguel Turrubiates <miguel_tf@yahoo.com>
 *
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', [
	'Class:ModuleInstallation/Attribute:comment' => 'Comentario',
	'Class:ModuleInstallation/Attribute:installed' => 'Instalado en',
	'Class:ModuleInstallation/Attribute:name' => 'Nombre',
	'Class:ModuleInstallation/Attribute:version' => 'Versión',
	'Menu:iTopUpdate' => 'Actualización de aplicación',
	'Menu:iTopUpdate+' => 'Actualización de aplicación',
	'iTopUpdate:Error:BadFileContent' => 'El archivo de actualización no es correcto',
	'iTopUpdate:Error:BadFileFormat' => 'El archivo de actualización no es un archivo zip',
	'iTopUpdate:Error:BadItopProduct' => 'El archivo de actualización no es compatible con su producto',
	'iTopUpdate:Error:Copy' => 'Error, no puedo copiar \'%1$s\' a \'%2$s\'',
	'iTopUpdate:Error:CorruptedFile' => 'El archivo %1$s está corrupto',
	'iTopUpdate:Error:FileNotFound' => 'Archivo no encontrado',
	'iTopUpdate:Error:FileUploadMaxSizeTooSmall' => 'El archivo de actualización parece demasiado pequeño. Por favor cambie la configuración PHP.',
	'iTopUpdate:Error:InvalidToken' => 'Token inválido',
	'iTopUpdate:Error:MissingFile' => 'Archivo no encontrado: %1$s',
	'iTopUpdate:Error:MissingFunction' => 'Imposible comenzar actualización, función no disponible',
	'iTopUpdate:Error:NoFile' => 'Archivo no seleccionado',
	'iTopUpdate:Error:UpdateFailed' => 'La actualización ha fallado',
	'iTopUpdate:UI:Action' => 'Actualización',
	'iTopUpdate:UI:Back' => 'Volver',
	'iTopUpdate:UI:Backup' => 'Respaldo generado antes de actualizar',
	'iTopUpdate:UI:CanCoreUpdate:Error' => 'La revisión del sistema de archivos falló (%1$s)',
	'iTopUpdate:UI:CanCoreUpdate:ErrorFileNotExist' => 'La revisión del sistema de archivos falló (Archivo no existe %1$s)',
	'iTopUpdate:UI:CanCoreUpdate:Failed' => 'La revisión del sistema de archivos falló',
	'iTopUpdate:UI:CanCoreUpdate:Loading' => 'Revisando sistema de archivos',
	'iTopUpdate:UI:CanCoreUpdate:No' => 'La aplicación no puede ser actualizada: %1$s',
	'iTopUpdate:UI:CanCoreUpdate:Warning' => 'Advertencia: la actualización de la aplicación puede fallar: %1$s',
	'iTopUpdate:UI:CanCoreUpdate:Yes' => 'La aplicación puede ser actualizada',
	'iTopUpdate:UI:Cancel' => 'Cancelar',
	'iTopUpdate:UI:CannotUpdateUseSetup' => 'Debe usar <a href="%1$s">setup</a> para actualizar la aplicación.<br />Algunos archivos modificados fueron detectados, una actualización parcial no puede ser realizada.',
	'iTopUpdate:UI:CheckInProgress' => 'Please wait during integrity check~~',
	'iTopUpdate:UI:CheckUpdate' => 'Verificar archivo de actualización',
	'iTopUpdate:UI:ConfirmInstallFile' => 'Usted va a instalar %1$s',
	'iTopUpdate:UI:Continue' => 'Continuar',
	'iTopUpdate:UI:CurrentVersion' => 'Versión instalada actualmente',
	'iTopUpdate:UI:DBDiskSpace' => 'Espacio en disco de base de datos',
	'iTopUpdate:UI:DiskFreeSpace' => 'Espacio libre en el dispositivo',
	'iTopUpdate:UI:DoBackup:Label' => 'Respaldo de archivos y base de datos',
	'iTopUpdate:UI:DoBackup:Warning' => 'El respaldo no está recomendado por el limitado espacio en el dispositivo',
	'iTopUpdate:UI:DoFilesArchive' => 'Respaldar archivos de aplicación',
	'iTopUpdate:UI:DoUpdate' => 'Actualizar',
	'iTopUpdate:UI:FileUploadMaxSize' => 'Máximo tamaño de carga de archivos',
	'iTopUpdate:UI:History' => 'Historial de versiones',
	'iTopUpdate:UI:ItopDiskSpace' => 'Espacio en disco de '.ITOP_APPLICATION_SHORT,
	'iTopUpdate:UI:MaintenanceModeActive' => 'La aplicación está actualmente en mantenimiento, ningún usuario puede acceder. UStede debe ejecutar la instalación o restaturar la aplicación para regresar al modo normal.',
	'iTopUpdate:UI:NewVersion' => 'Nueva versión instalada',
	'iTopUpdate:UI:PageTitle' => 'Actualización de aplicación',
	'iTopUpdate:UI:PostMaxSize' => 'Valor post_max_size en PHP ini: %1$s',
	'iTopUpdate:UI:Progress' => 'Progreso de actualización',
	'iTopUpdate:UI:RestoreArchive' => 'Usted puede restaurar su aplicación desde el archivo \'%1$s\'',
	'iTopUpdate:UI:RestoreBackup' => 'Usted puede restaurar la base de datos desde \'%1$s\'',
	'iTopUpdate:UI:RunSetup' => 'Ejecutar instalación',
	'iTopUpdate:UI:SelectUpdateFile' => 'Seleccione un archivo de actualización para subir',
	'iTopUpdate:UI:ServerFile' => 'Ruta del paquete disponible en el servidor',
	'iTopUpdate:UI:Setup' => ITOP_APPLICATION_SHORT.' Setup~~',
	'iTopUpdate:UI:SetupLaunch' => 'Launch '.ITOP_APPLICATION_SHORT.' Setup~~',
	'iTopUpdate:UI:SetupLaunchConfirm' => 'This will launch '.ITOP_APPLICATION_SHORT.' setup, are you sure?~~',
	'iTopUpdate:UI:SetupMessage:Backup' => 'Respaldo de base de datos',
	'iTopUpdate:UI:SetupMessage:CheckCompile' => 'Revisar actualización de aplicación',
	'iTopUpdate:UI:SetupMessage:Compile' => 'Actualizar aplicación y base de datos',
	'iTopUpdate:UI:SetupMessage:CopyFiles' => 'Copiar archivos de nueva version',
	'iTopUpdate:UI:SetupMessage:EnterMaintenance' => 'Entrando en modo mantenimiento',
	'iTopUpdate:UI:SetupMessage:ExitMaintenance' => 'Saliendo del modo mantenimiento',
	'iTopUpdate:UI:SetupMessage:FilesArchive' => 'Respaldar archivos de aplicación',
	'iTopUpdate:UI:SetupMessage:Ready' => 'Listo para empezar',
	'iTopUpdate:UI:SetupMessage:UpdateDatabase' => 'Actualizar base de datos',
	'iTopUpdate:UI:SetupMessage:UpdateDone' => 'Actualización completada',
	'iTopUpdate:UI:Status' => 'Estado',
	'iTopUpdate:UI:UpdateDone' => 'Actualización éxitosa',
	'iTopUpdate:UI:UploadArchive' => 'Selecione un paquete para subir',
	'iTopUpdate:UI:UploadMaxFileSize' => 'Valor upload_max_filesize en PHP ini: %1$s',
	'iTopUpdate:UI:WarningReadOnlyDuringUpdate' => 'Durante la actualización, la aplicación estará en modo sólo lectura.',
	'iTopUpdate:UI:WithDBBackup' => 'Respaldo de base de datos',
	'iTopUpdate:UI:WithFilesBackup' => 'Respaldo de archivos de aplicación',
	'iTopUpdate:UI:WithoutBackup' => 'No hay respaldos planificados',
	'itop-core-update/Operation:ConfirmUpdate/Title' => 'Confirmar actualización de la aplicación',
	'itop-core-update/Operation:SelectUpdateFile/Title' => 'Seleccionar archivo',
	'itop-core-update/Operation:UpdateCoreFiles/Title' => 'Actualizando aplicación',
	'itop-core-update/Operation:UpdateDone/Title' => 'Actualización de aplicación terminada',
	'itop-core-update:UI:ConfirmUpdate' => 'Confirmar actualización',
	'itop-core-update:UI:SelectUpdateFile' => 'Seleccionar archivo',
	'itop-core-update:UI:UpdateCoreFiles' => 'Actualizar aplicación',
	'itop-core-update:UI:UpdateDone' => 'Actualización realizada',
]);

==> iTop-3.2.2-1-17851.zip: web/datamodels/2.x/itop-core-update/dictionaries/es_cr.dict.itop-core-update.php <==
<?php
/**
 * Spanish Localized data
 *
 * @copyright Copyright (C) 2010-2024 Combodo SAS
 * @license    https://opensource.org/licenses/AGPL-3.0
 * @author Miguel Turrubiates <miguel_tf@yahoo.com>
 * @notas       Utilizar codificación UTF-8 para mostrar acentos y otros caracteres especiales 
 */
Dict::Add('ES CR', 'Spanish', 'Español, Castellano', array(
	'iTopUpdate:UI:PageTitle' => 'Actualización de aplicación',
	'itop-core-update:UI:SelectUpdateFile' => 'Seleccionar archivo',
	'itop-core-update:UI:ConfirmUpdate' => 'Confirmar actualización',
	'itop-core-update:UI:UpdateCoreFiles' => 'Actualizar aplicación',
	'iTopUpdate:UI:MaintenanceModeActive' => 'La aplicación está actualmente en mantenimiento, ningún usuario puede acceder. UStede debe ejecutar la instalación o restaturar la aplicación para regresar al modo normal.',
	'itop-core-update:UI:UpdateDone' => 'Actualización realizada',
	'itop-core-update/Operation:SelectUpdateFile/Title' => 'Seleccionar archivo',
	'itop-core-update/Operation:ConfirmUpdate/Title' => 'Confirmar actualización de la aplicación',
	'itop-core-update/Operation:UpdateCoreFiles/Title' => 'Actualizando aplicación',
	'itop-core-update/Operation:UpdateDone/Title' => 'Actualización de aplicación terminada',
	'iTopUpdate:UI:SelectUpdateFile' => 'Seleccione un archivo de actualización para subir',
	'iTopUpdate:UI:CheckUpdate' => 'Verificar archivo de actualización',
	'iTopUpdate:UI:ConfirmInstallFile' => 'Usted va a instalar %1$s',
	'iTopUpdate:UI:DoUpdate' => 'Actualizar',
	'iTopUpdate:UI:CurrentVersion' => 'Versión instalada actualmente',
	'iTopUpdate:UI:NewVersion' => 'Nueva versión instalada',
	'iTopUpdate:UI:Back' => 'Volver',
	'iTopUpdate:UI:Cancel' => 'Cancelar',
	'iTopUpdate:UI:Continue' => 'Continuar',
	'iTopUpdate:UI:RunSetup' => 'Ejecutar instalación',
	'iTopUpdate:UI:WithDBBackup' => 'Respaldo de base de datos',
	'iTopUpdate:UI:WithFilesBackup' => 'Respaldo de archivos de aplicación',
	'iTopUpdate:UI:WithoutBackup' => 'No hay respaldos planificados',
	'iTopUpdate:UI:Backup' => 'Respaldo generado antes de actualizar',
	'iTopUpdate:UI:DoFilesArchive' => 'Respaldar archivos de aplicación',
	'iTopUpdate:UI:UploadArchive' => 'Selecione un paquete para subir',
	'iTopUpdate:UI:ServerFile' => 'Ruta del paquete disponible en el servidor',
	'iTopUpdate:UI:WarningReadOnlyDuringUpdate' => 'Durante la actualización, la aplicación estará en modo sólo lectura.',
	'iTopUpdate:UI:Status' => 'Estado',
	'iTopUpdate:UI:Action' => 'Actualización',
	'iTopUpdate:UI:Setup' => 'Configuración '.ITOP_APPLICATION_SHORT,
	'iTopUpdate:UI:History' => 'Historial de versiones',
	'iTopUpdate:UI:Progress' => 'Progreso de actualización',
	'iTopUpdate:UI:DoBackup:Label' => 'Respaldo de archivos y base de datos',
	'iTopUpdate:UI:DoBackup:Warning' => 'El respaldo no está recomendado por el limitado espacio en el dispositivo',
	'iTopUpdate:UI:DiskFreeSpace' => 'Espacio libre en el dispositivo',
	'iTopUpdate:UI:ItopDiskSpace' => 'Espacio en disco de '.ITOP_APPLICATION_SHORT,
	'iTopUpdate:UI:DBDiskSpace' => 'Espacio en disco de base de datos',
	'iTopUpdate:UI:FileUploadMaxSize' => 'Máximo tamaño de carga de archivos',
	'iTopUpdate:UI:PostMaxSize' => 'Valor post_max_size en PHP ini: %1$s',
	'iTopUpdate:UI:UploadMaxFileSize' => 'Valor upload_max_filesize en PHP ini: %1$s',
	'iTopUpdate:UI:CanCoreUpdate:Loading' => 'Revisando sistema de archivos',
	'iTopUpdate:UI:CanCoreUpdate:Error' => 'La revisión del sistema de archivos falló (%1$s)',
	'iTopUpdate:UI:CanCoreUpdate:ErrorFileNotExist' => 'La revisión del sistema de archivos falló (Archivo no existe %1$s)',
	'iTopUpdate:UI:CanCoreUpdate:Failed' => 'La revisión del sistema de archivos falló',
	'iTopUpdate:UI:CanCoreUpdate:Yes' => 'La aplicación puede ser actualizada',
	'iTopUpdate:UI:CanCoreUpdate:No' => 'La aplicación no puede ser actualizada: %1$s',
	'iTopUpdate:UI:CanCoreUpdate:Warning' => 'Advertencia: la actualización de la aplicación puede fallar: %1$s',
	'iTopUpdate:UI:CannotUpdateUseSetup' => 'Debe usar <a href="%1$s">setup</a> para actualizar la aplicación.<br />Algunos archivos modificados fueron detectados, una actualización parcial no puede ser realizada.',
	'iTopUpdate:UI:CheckInProgress' => 'Espere durante la verificación de integridad',
	'iTopUpdate:UI:SetupLaunch' => 'Inicie configuración '.ITOP_APPLICATION_SHORT,
	'iTopUpdate:UI:SetupLaunchConfirm' => 'Esto iniciará configuración '.ITOP_APPLICATION_SHORT.', ¿Está seguro?',
	'iTopUpdate:UI:FastSetupLaunch' => 'Fast Setup~~',
	'iTopUpdate:UI:SetupMessage:Ready' => 'Listo para empezar',
	'iTopUpdate:UI:SetupMessage:EnterMaintenance' => 'Entrando en modo mantenimiento',
	'iTopUpdate:UI:SetupMessage:Backup' => 'Respaldo de base de datos',
	'iTopUpdate:UI:SetupMessage:FilesArchive' => 'Respaldar archivos de aplicación',
	'iTopUpdate:UI:SetupMessage:CopyFiles' => 'Copiar archivos de nueva version',
	'iTopUpdate:UI:SetupMessage:CheckCompile' => 'Revisar actualización de aplicación',
	'iTopUpdate:UI:SetupMessage:Compile' => 'Actualizar aplicación y base de datos',
	'iTopUpdate:UI:SetupMessage:UpdateDatabase' => 'Actualizar base de datos',
	'iTopUpdate:UI:SetupMessage:ExitMaintenance' => 'Saliendo del modo mantenimiento',
	'iTopUpdate:UI:SetupMessage:UpdateDone' => 'Actualización completada',
	'iTopUpdate:Error:MissingFunction' => 'Imposible comenzar actualización, función no disponible',
	'iTopUpdate:Error:MissingFile' => 'Archivo no encontrado: %1$s',
	'iTopUpdate:Error:CorruptedFile' => 'El archivo %1$s está corrupto',
	'iTopUpdate:Error:BadFileFormat' => 'El archivo de actualización no es un archivo zip',
	'iTopUpdate:Error:BadFileContent' => 'El archivo de actualización no es correcto',
	'iTopUpdate:Error:BadItopProduct' => 'El archivo de actualización no es compatible con su producto',
	'iTopUpdate:Error:Copy' => 'Error, no puedo copiar \'%1$s\' a \'%2$s\'',
	'iTopUpdate:Error:FileNotFound' => 'Archivo no encontrado',
	'iTopUpdate:Error:NoFile' => 'Archivo no seleccionado',
	'iTopUpdate:Error:InvalidToken' => 'Token inválido',
	'iTopUpdate:Error:UpdateFailed' => 'La actualización ha fallado',
	'iTopUpdate:Error:FileUploadMaxSizeTooSmall' => 'El archivo de actualización parece demasiado pequeño. Por favor cambie la configuración PHP.',
	'iTopUpdate:UI:RestoreArchive' => 'Usted puede restaurar su aplicación desde el archivo \'%1$s\'',
	'iTopUpdate:UI:RestoreBackup' => 'Usted puede restaurar la base de datos desde \'%1$s\'',
	'iTopUpdate:UI:UpdateDone' => 'Actualización éxitosa',
	'Menu:iTopUpdate' => 'Actualización de aplicación',
	'Menu:iTopUpdate+' => 'Actualización de aplicación',
	'Class:ModuleInstallation/Attribute:installed' => 'Instalado en',
	'Class:ModuleInstallation/Attribute:name' => 'Nombre',
	'Class:ModuleInstallation/Attribute:version' => 'Versión',
	'Class:ModuleInstallation/Attribute:comment' => 'Comentario',
));
